@@ -1,11 +1,11 @@
 from db_utils.timer import timer
+from db_utils import default_path
 import numpy as np
 import pandas as pd
 import sqlparse
 import configparser
 import sqlparse
-
-
+import os
 
 class db_connect():
     '''
@@ -13,19 +13,27 @@ class db_connect():
     python database API specification v2.0
     https://www.python.org/dev/peps/pep-0249/#connection-methods
     '''
-
-    def __init__(self, db_name=None, config_file=None):
+    
+    def __init__(self, db_name=None, config_file=default_path):
+        '''
+        config_file <string> default configuration location ~/.databases.conf
+        '''
         if db_name is None: 
             raise Exception("Please provide db_name=the-section-in-your-config-file as an argument") 
         if config_file is None: 
             raise Exception("Please provide config_file=/path/to/your/file as an argument") 
         try: 
-            open(config_file)
+            cp = configparser.ConfigParser()
+            cp.read(config_file)
         except: 
             raise Exception("Cannot open config_file. Please check the path to your config files") 
 
+        config_dict = {}
+        [config_dict.__setitem__(i, cp.get(db_name, i)) for i in cp.options(db_name)]
+
         self.db_name = db_name
         self.config_file = config_file
+        self.config_dict = config_dict
 
 
     def connect_to_db(self):
